summaryrefslogtreecommitdiff
path: root/LedgerSMB/Sysconfig.pm
diff options
context:
space:
mode:
Diffstat (limited to 'LedgerSMB/Sysconfig.pm')
-rw-r--r--LedgerSMB/Sysconfig.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/LedgerSMB/Sysconfig.pm b/LedgerSMB/Sysconfig.pm
index 1634bfcc..7bcff26d 100644
--- a/LedgerSMB/Sysconfig.pm
+++ b/LedgerSMB/Sysconfig.pm
@@ -1,6 +1,6 @@
# This is the new configuration file for LedgerSMB. Eventually all system
# configuration directives will go here, This will probably not fully replace
# the ledger-smb.conf until 1.3, however.
package LedgerSMB::Sysconfig;
@@ -62,7 +62,7 @@ $localepath = 'locale/po';
);
my %config;
-read_config('ledger-smb.conf' => %config) or die;
+read_config('ledgersmb.conf' => %config) or die;
$logging = $config{''}{logging} if $config{''}{logging};
$check_max_invoices = $config{''}{check_max_invoices} if
@@ -1,6 +1,6 @@
# This is the new configuration file for LedgerSMB. Eventually all system
# configuration directives will go here, This will probably not fully replace
-# the ledger-smb.conf until 1.3, however.
+# the ledgersmb.conf until 1.3, however.
package LedgerSMB::Sysconfig;